@@ -439,7 +439,7 @@ class TaskMonkClient:
             local_path where the output is saved
 
         """
-        url = self._base_url + urlConfig.URLS['Project'] + self._project_id + '/batch/' + batch_id + '/output/file?output_format=' + output_format
+        url = self._base_url + urlConfig.URLS['Project'] + '/' + self._project_id + '/batch/' + batch_id + '/output/file?output_format=' + output_format
         data = json.dumps({'field_names': fields, 'completedOnly': completed_only})
         response = apiCall.post(self.__get_token(), url,self._proxy, data, 30)
         file_url = response['file_url']
